@@ -26,9 +26,9 @@
 #' components stand out as peaks.
 #'
 #' @param x a numerical vector OR an object of class \code{UPb},
-#'     \code{PbPb}, \code{ArAr}, \code{UThHe}, \code{fissiontracks},
-#'     \code{ReOs}, \code{RbSr}, \code{SmNd}, \code{LuHf}, \code{ThU}
-#'     or \code{detritals}
+#'     \code{PbPb}, \code{ArAr}, \code{KCa}, \code{UThHe},
+#'     \code{fissiontracks}, \code{ReOs}, \code{RbSr}, \code{SmNd},
+#'     \code{LuHf}, \code{ThU} or \code{detritals}
 #' @seealso \code{\link{kde}}, \code{\link{radialplot}}
 #' @rdname cad
 #' @export
@@ -117,14 +117,16 @@ cad.UPb <- function(x,pch=NA,verticals=TRUE,xlab='age [Ma]',
 }
 #' @param i2i `isochron to intercept': calculates the initial (aka
 #'     `inherited', `excess', or `common')
-#'     \eqn{^{40}}Ar/\eqn{^{36}}Ar, \eqn{^{207}}Pb/\eqn{^{204}}Pb,
-#'     \eqn{^{87}}Sr/\eqn{^{86}}Sr, \eqn{^{143}}Nd/\eqn{^{144}}Nd,
-#'     \eqn{^{187}}Os/\eqn{^{188}}Os, \eqn{^{230}}Th/\eqn{^{232}}Th or
-#'     \eqn{^{176}}Hf/\eqn{^{177}}Hf ratio from an isochron
-#'     fit. Setting \code{i2i} to \code{FALSE} uses the default values
-#'     stored in \code{settings('iratio',...)}  or zero (for the Pb-Pb
-#'     method). When applied to data of class \code{ThU}, setting
-#'     \code{i2i} to \code{TRUE} applies a detrital Th-correction.
+#'     \eqn{^{40}}Ar/\eqn{^{36}}Ar, \eqn{^{40}}Ca/\eqn{^{44}}Ca,
+#'     \eqn{^{207}}Pb/\eqn{^{204}}Pb, \eqn{^{87}}Sr/\eqn{^{86}}Sr,
+#'     \eqn{^{143}}Nd/\eqn{^{144}}Nd, \eqn{^{187}}Os/\eqn{^{188}}Os,
+#'     \eqn{^{230}}Th/\eqn{^{232}}Th or \eqn{^{176}}Hf/\eqn{^{177}}Hf
+#'     ratio from an isochron fit. Setting \code{i2i} to \code{FALSE}
+#'     uses the default values stored in \code{settings('iratio',...)}
+#'     or zero (for the Pb-Pb method). When applied to data of class
+#'     \code{ThU}, setting \code{i2i} to \code{TRUE} applies a
+#'     detrital Th-correction.
+#' 
 #' @references Vermeesch, P., 2007. Quantitative geomorphology of the
 #'     White Mountains (California) using detrital apatite fission
 #'     track thermochronology. Journal of Geophysical Research: Earth
@@ -147,6 +149,13 @@ cad.ArAr <- function(x,pch=NA,verticals=TRUE,
     tt <- ArAr.age(x,i2i=i2i)[,1]
     cad.default(tt,pch=pch,verticals=verticals,xlab=xlab,col=col,...)
 }
+#' @rdname cad
+#' @export
+cad.KCa <- function(x,pch=NA,verticals=TRUE,
+                    xlab='age [Ma]',col='black',i2i=FALSE,...){
+    tt <- KCa.age(x,i2i=i2i)[,1]
+    cad.default(tt,pch=pch,verticals=verticals,xlab=xlab,col=col,...)
+}
 #' @param detritus detrital \eqn{^{230}}Th correction (only applicable
 #'     when \code{x$format == 1} or \code{2}.
 #'
